@@ -1,3 +1,4 @@
+import copy
 import warnings
 from functools import wraps, partial
 from typing import Literal
@@ -5,7 +6,7 @@ from platon._utils.abi import filter_by_name
 from platon.contract import ContractFunction
 from platon.types import ABI
 from platon_typing import HexStr, AnyAddress
-
+from copy import copy
 from platon_aide.base.module import Module
 from platon_aide.utils import contract_call, contract_transaction
 
@@ -23,7 +24,7 @@ class Contract(Module):
              vm_type: Literal['solidity', 'wasm'] = 'solidity',
              ):
         self.__build_contract(abi, bytecode, address, vm_type)
-        return self
+        return copy(self)
 
     def deploy(self,
                abi,
@@ -47,7 +48,7 @@ class Contract(Module):
 
         self.__build_contract(abi, bytecode, address, vm_type)
 
-        return self
+        return copy(self)
 
     def __build_contract(self,
                          abi,
