@@ -1,9 +1,7 @@
 from platon_aide.utils.utils import (
     get_web3,
     get_gql,
-    send_transaction,
-    get_transaction_result,
     contract_call,
     contract_transaction,
-    ec_recover,
+    mock_duplicate_sign,
 )
